this trait describes a specific steam web api
a steam web api endpoint usually defines as follow
{HTTP_METHOD} https://{host}/{interface}/{method}/{version}?{queries}
the key parameter is not treated as part of endpoint itself,
but rather an authencation parameter hence not include here