Crate fume_core

Crate fume_core 

Modules

app
player
user
util

Macros

quoted_number

Structs

Response
A generic response type

Enums

ResponseResult
A generic response status type

Traits

Api
this trait describes a specific steam web api a steam web api endpoint usually defines as follow {HTTP_METHOD} https://{host}/{interface}/{method}/{version}?{queries} the key parameter is not treated as part of endpoint itself, but rather an authencation parameter hence not include here
Param